@@ -7,7 +7,7 @@ class ChromeException(Exception):
 
 
 class ChromePathNotFound(ChromeException):
-    def __init__(self, msg='Chrome браузер не найден', *args, **kwargs):
+    def __init__(self, msg: str = 'Chrome браузер не найден', *args, **kwargs) -> None:
         super().__init__(msg, *args, **kwargs)
 
 
