@@ -21,9 +21,9 @@ class CSVWriter(FileWriter):
         # Complex mapping means its content could contain several entities bound by user settings.
         # For example: phone -> phone_1, phone_2, ..., phone_n
         return {
-            'phone': 'Телефон', 'email': 'E-mail',
-            'website': 'Веб-сайт', 'instagram': 'Instagram', 'twitter': 'Twitter', 'facebook': 'Facebook',
-            'vkontakte': 'ВКонтакте', 'youtube': 'YouTube', 'skype': 'Skype'
+            'phone': 'Телефон', 'email': 'E-mail', 'website': 'Веб-сайт', 'instagram': 'Instagram',
+            'twitter': 'Twitter', 'facebook': 'Facebook', 'vkontakte': 'ВКонтакте', 'whatsapp': 'WhatsApp',
+            'viber': 'Viber', 'telegram': 'Telegram', 'youtube': 'YouTube', 'skype': 'Skype'
         }
 
     @property
@@ -33,7 +33,7 @@ class CSVWriter(FileWriter):
             'address': 'Адрес', 'address_comment': 'Комментарий к адресу',
             'postcode': 'Почтовый индекс', 'living_area': 'Микрорайон', 'district': 'Район', 'city': 'Город',
             'district_area': 'Округ', 'region': 'Регион', 'country': 'Страна', 'schedule': 'Часы работы',
-            'timezone': 'Часовой пояс',
+            'timezone': 'Часовой пояс', 'general_rating': 'Рейтинг', 'general_review_count': 'Количество отзывов'
         }
 
         # Expand complex mapping
@@ -179,6 +179,7 @@ class CSVWriter(FileWriter):
                 errors.append(f'[*] Поле: {path}, значение: {arg}, ошибка: {error_msg}')
 
             error_str = 'Ошибка парсинга:\n' + '\n'.join(errors)
+            error_str += '\nДокумент каталога: ' + str(catalog_doc)
             logger.error(error_str)
 
             return {}
@@ -190,6 +191,10 @@ class CSVWriter(FileWriter):
         # Address
         data['address'] = catalog_item.address_name
 
+        # Reviews
+        data['general_rating'] = catalog_item.reviews.general_rating
+        data['general_review_count'] = catalog_item.reviews.general_review_count
+
         # Point location
         if catalog_item.point:
             data['point_lat'] = catalog_item.point.lat  # Latitude (широта)
@@ -247,10 +252,16 @@ class CSVWriter(FileWriter):
                         if self._options.csv.add_comments and contact.comment:
                             data[data_name] += ' (%s)' % contact.comment
 
-            # Urls
-            for t in ['website', 'vkontakte', 'instagram', 'facebook', 'twitter', 'youtube']:
+            # URLs
+            for t in ['website', 'vkontakte', 'whatsapp', 'viber', 'telegram',
+                      'instagram', 'facebook', 'twitter', 'youtube', 'skype']:
                 append_contact(t, ['url'])
 
+            # Remove arguments from WhatsApp URL
+            for field in data:
+                if field.startswith('whatsapp') and data[field]:
+                    data[field] = data[field].split('?')[0]
+
             # Values
             for t in ['email', 'skype']:
                 append_contact(t, ['value'])
